@@ -120,15 +120,22 @@ class TestNodeCache(test_base.NodeTest):
 
     def test_active_macs(self):
         session = db.get_writer_session()
+        uuid2 = uuidutils.generate_uuid()
         with session.begin():
             db.Node(uuid=self.node.uuid,
                     state=istate.States.starting).save(session)
+            db.Node(uuid=uuid2,
+                    state=istate.States.starting,
+                    manage_boot=False).save(session)
             values = [('mac', '11:22:11:22:11:22', self.uuid),
-                      ('mac', '22:11:22:11:22:11', self.uuid)]
+                      ('mac', '22:11:22:11:22:11', self.uuid),
+                      ('mac', 'aa:bb:cc:dd:ee:ff', uuid2)]
             for value in values:
                 db.Attribute(uuid=uuidutils.generate_uuid(), name=value[0],
                              value=value[1], node_uuid=value[2]).save(session)
-        self.assertEqual({'11:22:11:22:11:22', '22:11:22:11:22:11'},
+        self.assertEqual({'11:22:11:22:11:22', '22:11:22:11:22:11',
+                          # We still need to serve DHCP to unmanaged nodes
+                          'aa:bb:cc:dd:ee:ff'},
                          node_cache.active_macs())
 
     def test__list_node_uuids(self):
@@ -230,6 +237,7 @@ class TestNodeCacheFind(test_base.NodeTest):
 
     def test_bmc(self):
         res = node_cache.find_node(bmc_address='1.2.3.4')
+        self.addCleanup(res.release_lock)
         self.assertEqual(self.uuid, res.uuid)
         self.assertTrue(
             datetime.datetime.utcnow() - datetime.timedelta(seconds=60)
@@ -244,8 +252,10 @@ class TestNodeCacheFind(test_base.NodeTest):
                             bmc_address='1.2.3.4',
                             mac=self.macs2)
         res = node_cache.find_node(bmc_address='1.2.3.4', mac=self.macs)
+        self.addCleanup(res.release_lock)
         self.assertEqual(self.uuid, res.uuid)
         res = node_cache.find_node(bmc_address='1.2.3.4', mac=self.macs2)
+        self.addCleanup(res.release_lock)
         self.assertEqual(uuid2, res.uuid)
 
     def test_same_bmc_raises(self):
@@ -258,6 +268,7 @@ class TestNodeCacheFind(test_base.NodeTest):
 
     def test_macs(self):
         res = node_cache.find_node(mac=['11:22:33:33:33:33', self.macs[1]])
+        self.addCleanup(res.release_lock)
         self.assertEqual(self.uuid, res.uuid)
         self.assertTrue(
             datetime.datetime.utcnow() - datetime.timedelta(seconds=60)
@@ -280,6 +291,7 @@ class TestNodeCacheFind(test_base.NodeTest):
     def test_both(self):
         res = node_cache.find_node(bmc_address='1.2.3.4',
                                    mac=self.macs)
+        self.addCleanup(res.release_lock)
         self.assertEqual(self.uuid, res.uuid)
         self.assertTrue(
             datetime.datetime.utcnow() - datetime.timedelta(seconds=60)
@@ -457,7 +469,7 @@ class TestNodeCacheGetNode(test_base.NodeTest):
                     state=istate.States.starting,
                     started_at=started_at).save(session)
         info = node_cache.get_node(self.uuid, locked=True)
-
+        self.addCleanup(info.release_lock)
         self.assertEqual(self.uuid, info.uuid)
         self.assertEqual(started_at, info.started_at)
         self.assertIsNone(info.finished_at)
@@ -850,6 +862,7 @@ class TestNodeCacheGetByPath(test_base.NodeTest):
 class TestLock(test_base.NodeTest):
     def test_acquire(self, get_lock_mock):
         node_info = node_cache.NodeInfo(self.uuid)
+        self.addCleanup(node_info.release_lock)
         self.assertFalse(node_info._locked)
         get_lock_mock.assert_called_once_with(self.uuid)
         self.assertFalse(get_lock_mock.return_value.acquire.called)
@@ -873,6 +886,7 @@ class TestLock(test_base.NodeTest):
 
     def test_acquire_non_blocking(self, get_lock_mock):
         node_info = node_cache.NodeInfo(self.uuid)
+        self.addCleanup(node_info.release_lock)
         self.assertFalse(node_info._locked)
         get_lock_mock.return_value.acquire.side_effect = iter([False, True])
 
